==> velocity-animate-0.8.0.tgz: package/README.md <==
##Velocity

**Docs**  
http://VelocityJS.org

**Quickstart**  
`<script src="//cdn.jsdelivr.net/jquery.velocity/0.7.0/jquery.velocity.min.js"></script>`

**Package Managers**  
Bower package is *velocity*. NPM package is *velocity-animate*.

**Coming Soon**  
jQuery dependency removal and Zepto support.

###**Learn**

- **UI Pack**: http://www.smashingmagazine.com/2014/06/18/faster-ui-animations-with-velocity-js/
- **Performance comparisons**: http://davidwalsh.name/css-js-animation
- **Performance optimizations**: http://www.sitepoint.com/incredibly-fast-ui-animation-using-velocity-js/
- **Workflow**: http://css-tricks.com/improving-ui-animation-workflow-velocity-js

###**Comparisons**

- **Famo.us** is a full-fledged *mobile app framework* built around a physics engine.
- **GSAP** is a fast, multi-purpose *animation platform*. It inspired me to pursue the development of Velocity.
- **Velocity** is a lightweight tool for drastically improving *UI animation performance and workflow*.

###**New Features**

- 0.6.0: Can set `display: "auto"` and can set `visibility`. See http://VelocityJS.org/#displayAndVisibility.
- 0.5.0: Promises support. See http://VelocityJS.org/#promises.
- 0.3.0-0.4.0: SVG animation support. See http://VelocityJS.org/#svg.
- 0.2.0: Added step easing. See http://VelocityJS.org/#easing.
- 0.1.0: The `stop` command now stops animations *immediately* (instead of just clearing the remainder of the animation queue). No other backwards-incompatible changes were made. See http://VelocityJS.org/#stop.

====

[MIT License](LICENSE). © Julian Shapiro (http://twitter.com/shapiro).

==> velocity-animate-0.9.0.tgz: package/README.md <==
##Velocity

**Docs**  
http://VelocityJS.org

**Quickstart**  
`<script src="//cdn.jsdelivr.net/jquery.velocity/0.8.0/jquery.velocity.min.js"></script>`

**Package Managers**  
Bower package is *velocity*. NPM package is *velocity-animate*.

**Coming Soon**  
jQuery dependency removal and Zepto support.

###**Learn**

- **UI Pack**: http://www.smashingmagazine.com/2014/06/18/faster-ui-animations-with-velocity-js/
- **Performance comparisons**: http://davidwalsh.name/css-js-animation
- **Performance optimizations**: http://www.sitepoint.com/incredibly-fast-ui-animation-using-velocity-js/
- **Workflow**: http://css-tricks.com/improving-ui-animation-workflow-velocity-js

###**Comparisons**

- **Famo.us** is a full-fledged *mobile app framework* built around a physics engine.
- **CSS transitions** are meant for simple interface flourishes triggered by hover states.
- **Velocity** is a tool for injecting rich motion design into your UI.

###**New Features**

- 0.8.0: Support for the vw/vh CSS units.
- 0.6.0: Can set `display: "auto"` and can set `visibility`. See http://VelocityJS.org/#displayAndVisibility.
- 0.5.0: Promises support. See http://VelocityJS.org/#promises.
- 0.3.0-0.4.0: SVG animation support. See http://VelocityJS.org/#svg.
- 0.2.0: Added step easing. See http://VelocityJS.org/#easing.
- 0.1.0: The `stop` command now stops animations *immediately* (instead of just clearing the remainder of the animation queue). No other backwards-incompatible changes were made. See http://VelocityJS.org/#stop.

====

[MIT License](LICENSE). © Julian Shapiro (http://twitter.com/shapiro).
